{% extends "agenda/base.html" %} {% load compress %} {% load i18n %} {% load staticfiles %} {% block agenda_content %} {% for schedule in request.event.schedules.all %}{% if schedule.version %} {% trans "Version" %} {{ schedule.version }} {% if not schedule.changes.count %} {% if schedule.changes.action == 'update' %}

{{ phrases.agenda.changelog_unchanged }}

{% else %}

{{ phrases.agenda.changelog_first }}

{% endif %} {% else %} {% if schedule.changes.new_talks|length > 0 %} {% if schedule.changes.new_talks|length > 1 %}

{{ phrases.agenda.changelog_new_talks }}

{% for talk in schedule.changes.new_talks %}
- »{{ talk.submission.title }}« {% if talks.submission.speakers.exists %} {% trans "by" %} {{ talk.submission.display_speaker_names }} {% endif %}
{% endfor %}

{% else %}

{{ phrases.agenda.changelog_new_talk }} {% for talk in schedule.changes.new_talks %} »{{ talk.submission.title }}« {% if talk.submission.speakers.exists %} {% trans "by" %} {{ talk.submission.display_speaker_names }} {% endif %} . {% endfor %} {% endif %}

{% endif %} {% if schedule.changes.canceled_talks|length > 0 %} {% if schedule.changes.canceled_talks|length > 1 %}

{{ phrases.agenda.changelog_canceled_talks }}

{% for talk in schedule.changes.canceled_talks %}
- »{{ talk.submission.title }}« {% if talk.submission.speakers.exists %} {% trans "by" %} {{ talk.submission.display_speaker_names }} {% endif %}
{% endfor %}

{% else %}

{{ phrases.agenda.changelog_canceled_talk }} {% for talk in schedule.changes.canceled_talks %} »{{ talk.submission.title }}« {% if talk.submission.speakers.exists %} {% trans "by" %} {{ talk.submission.display_speaker_names }}. {% endif %} {% endfor %}

{% endif %} {% endif %} {% if schedule.changes.moved_talks|length > 0 %} {% if schedule.changes.moved_talks|length > 1 %}

{{ phrases.agenda.changelog_moved_talks }}

{% for talk in schedule.changes.moved_talks %}
- »{{ talk.submission.title }}« {% if talk.submission.speakers.exists %} {% trans "by" %} {{ talk.submission.display_speaker_names }} {% endif %}
{% endfor %}

{% else %}

{{ phrases.agenda.changelog_moved_talk }} {% for talk in schedule.changes.moved_talks %} »{{ talk.submission.title }}« {% if talk.submission.speakers.exists %} {% trans "by" %} {{ talk.submission.display_speaker_names }} {% endif %} . {% endfor %}

{% endif %} {% endif %} {% endif %} {% endif %}{% endfor %} {% endblock %}